#[non_exhaustive]pub struct DeserializerOptions {
pub human_readable: Option<bool>,
}Expand description
Options used to configure a Deserializer. These can also be passed into
crate::from_bson_with_options and crate::from_document_with_options.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.human_readable: Option<bool>Whether the Deserializer should present itself as human readable or not.
The default is true.
Implementations
Sourceimpl DeserializerOptions
impl DeserializerOptions
Sourcepub fn builder() -> DeserializerOptionsBuilder
pub fn builder() -> DeserializerOptionsBuilder
Create a builder struct used to construct a DeserializerOptions.